@@ -71,10 +71,13 @@ sub _prepare {
     my $f = Feersum->endjinn;
     $f->use_socket($sock);
 
-    if ($self->{options}) {
-        # Plack::Runner puts these here
-        $self->{pre_fork} = delete $self->{options}{pre_fork};
+    if (my $opts = $self->{options}) {
+        $self->{$_} = delete $opts->{$_} for grep defined($opts->{$_}),
+            qw/pre_fork keepalive read_timeout max_connection_reqs/;
     }
+    $f->set_keepalive($_) for grep defined, delete $self->{keepalive};
+    $f->read_timeout($_) for grep $_, delete $self->{read_timeout};
+    $f->max_connection_reqs($_) for grep $_, delete $self->{max_connection_reqs};
 
     $self->{endjinn} = $f;
     return;
@@ -142,7 +145,7 @@ sub _fork_another {
             EV::break(EV::BREAK_ALL()) unless $self->{_n_kids};
             return;
         }
-        $self->_fork_another();
+        $self->_fork_another($slot);
     };
     return;
 }
@@ -226,6 +229,18 @@ Fork this many worker processes.
 The fork is run immediately at startup and after the app is loaded (i.e. in
 the C<run()> method).
 
+=item keepalive
+
+Enable/disable http keepalive requests.
+
+=item read_timeout
+
+Set read/keepalive timeout in seconds.
+
+=item max_connection_reqs
+
+Set max requests per connection in case of keepalive - 0(default) for unlimited.
+
 =item quiet
 
 Don't be so noisy. (default: on)
